luck_ring_plugin

A new Flutter plugin project.

Getting Started

This project is a starting point for a Flutter plug-in package, a specialized package that includes platform-specific implementation code for Android and/or iOS.

For help getting started with Flutter development, view the online documentation, which offers tutorials, samples, guidance on mobile development, and a full API reference.

Libraries

luck_ring_plugin
A Flutter plugin for interacting with Luck Ring / Coolwear smart rings.
luck_ring_plugin_method_channel
luck_ring_plugin_platform_interface