HealthData class

Aggregated health data from the Luck Ring / Coolwear device.

Constructors

HealthData({List<HeartRateReading> heartRate = const [], List<BloodOxygenReading> bloodOxygen = const [], List<BloodPressureReading> bloodPressure = const [], List<SleepRecord> sleep = const [], List<SportRecord> sport = const [], int? batteryLevel, DeviceInfo? deviceInfo, String? errorMessage})
Creates a new HealthData instance.
const
HealthData.fromMap(Map<String, dynamic> map)
Creates a HealthData instance from a JSON-compatible map.
factory

Properties

batteryLevel int?
Current battery level percentage (0-100).
final
bloodOxygen List<BloodOxygenReading>
List of blood oxygen (SpO2) measurements.
final
bloodPressure List<BloodPressureReading>
List of blood pressure measurements.
final
deviceInfo DeviceInfo?
Static device information.
final
errorMessage String?
Error message if data retrieval failed.
final
hashCode int
The hash code for this object.
no setterinherited
heartRate List<HeartRateReading>
List of heart rate measurements.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sleep List<SleepRecord>
List of sleep session records.
final
sport List<SportRecord>
List of activity and sport records.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this instance into a JSON-compatible map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited